@@ -12,12 +12,13 @@
 //! ```rust,no_run
 //! extern crate phf_codegen;
 //!
+//! use std::env;
 //! use std::fs::File;
 //! use std::io::{BufWriter, Write};
 //! use std::path::Path;
 //!
 //! fn main() {
-//!     let path = Path::new(env!("OUT_DIR")).join("codegen.rs");
+//!     let path = Path::new(&env::var("OUT_DIR").unwrap()).join("codegen.rs");
 //!     let mut file = BufWriter::new(File::create(&path).unwrap());
 //!
 //!     write!(&mut file, "static KEYWORDS: phf::Map<&'static str, Keyword> = ").unwrap();
@@ -76,7 +77,7 @@
 //! builder.entry("world", "2");
 //! // ...
 //! ```
-#![doc(html_root_url="http://sfackler.github.io/rust-phf/doc")]
+#![doc(html_root_url="http://sfackler.github.io/rust-phf/doc/v0.7.4")]
 extern crate phf_shared;
 extern crate phf_generator;
 
